@@ -1,5 +1,5 @@
 /* client-callback.c --- Example SASL client, with callback for user info.
- * Copyright (C) 2004-2012 Simon Josefsson
+ * Copyright (C) 2004-2019 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -101,7 +101,7 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
 
   /* Get user info from user. */
 
-  printf ("Callback invoked, for property %d.\n", prop);
+  printf ("Callback invoked, for property %u.\n", prop);
 
   switch (prop)
     {
