@@ -1,5 +1,5 @@
 /* client-xmpp-saml20.c --- Example XMPP SASL SAML20 client.
- * Copyright (C) 2004-2012 Simon Josefsson
+ * Copyright (C) 2004-2019 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -149,7 +149,7 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
       break;
 
     default:
-      printf ("Unknown property %d!  Don't worry.\n", prop);
+      printf ("Unknown property %u!  Don't worry.\n", prop);
       break;
     }
 
