@@ -1,5 +1,5 @@
 /* smtp-server-openid20.c --- Example SMTP server with OpenID 2.0 support
- * Copyright (C) 2012 Simon Josefsson
+ * Copyright (C) 2012-2019 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -209,7 +209,7 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
 
   switch (prop)
     {
-    case GSASL_REDIRECT_URL:
+    case GSASL_OPENID20_REDIRECT_URL:
       {
 	line = get_redirect_url (sctx);
 	if (line == NULL)
