@@ -1,5 +1,5 @@
 /* digest.c --- Generate a CRAM-MD5 hex encoded HMAC-MD5 response string.
- * Copyright (C) 2002-2012 Simon Josefsson
+ * Copyright (C) 2002-2019 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,6 +20,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
 
 /* Get prototype. */
