@@ -1,5 +1,5 @@
 /* free.h --- Free allocated data in DIGEST-MD5 token structures.
- * Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
+ * Copyright (C) 2004-2019 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -23,9 +23,6 @@
 /* Get prototypes. */
 #include "free.h"
 
-/* Get size_t. */
-#include <stddef.h>
-
 /* Get free. */
 #include <stdlib.h>
 
