@@ -1,5 +1,5 @@
 /* parser.c --- DIGEST-MD5 parser.
- * Copyright (C) 2002-2012 Simon Josefsson
+ * Copyright (C) 2002-2019 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,7 +21,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 /* Get prototypes. */
@@ -569,16 +569,12 @@ int
 digest_md5_parse_challenge (const char *challenge, size_t len,
 			    digest_md5_challenge * out)
 {
-  size_t inlen = len ? len : strlen (challenge);
-  char *subopts = malloc (inlen + 1);
+  char *subopts = len ? strndup (challenge, len) : strdup (challenge);
   int rc;
 
   if (!subopts)
     return -1;
 
-  memcpy (subopts, challenge, inlen);
-  subopts[inlen] = '\0';
-
   rc = parse_challenge (subopts, out);
 
   free (subopts);
@@ -590,16 +586,12 @@ int
 digest_md5_parse_response (const char *response, size_t len,
 			   digest_md5_response * out)
 {
-  size_t inlen = len ? len : strlen (response);
-  char *subopts = malloc (inlen + 1);
+  char *subopts = len ? strndup (response, len) : strdup (response);
   int rc;
 
   if (!subopts)
     return -1;
 
-  memcpy (subopts, response, inlen);
-  subopts[inlen] = '\0';
-
   rc = parse_response (subopts, out);
 
   free (subopts);
@@ -611,16 +603,12 @@ int
 digest_md5_parse_finish (const char *finish, size_t len,
 			 digest_md5_finish * out)
 {
-  size_t inlen = len ? len : strlen (finish);
-  char *subopts = malloc (inlen + 1);
+  char *subopts = len ? strndup (finish, len) : strdup (finish);
   int rc;
 
   if (!subopts)
     return -1;
 
-  memcpy (subopts, finish, inlen);
-  subopts[inlen] = '\0';
-
   rc = parse_finish (subopts, out);
 
   free (subopts);
