@@ -1,5 +1,5 @@
 /* gs2.h --- Prototypes for SASL mechanism GS2.
- * Copyright (C) 2006  Simon Josefsson
+ * Copyright (C) 2006-2019 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -25,34 +25,22 @@
 
 #include <gsasl.h>
 
-#define GSASL_GS2_KRB5_NAME "GS2-FNUO57PLKGM5XHGE"
+#define GSASL_GS2_KRB5_NAME "GS2-KRB5"
 
 extern Gsasl_mechanism gsasl_gs2_krb5_mechanism;
 
-extern int _gsasl_gs2_client_start (Gsasl_session * sctx,
-				    void **mech_data);
+extern int _gsasl_gs2_client_start (Gsasl_session * sctx, void **mech_data);
 extern int _gsasl_gs2_client_step (Gsasl_session * sctx,
 				   void *mech_data,
 				   const char *input, size_t input_len,
 				   char **output, size_t * output_len);
-extern void _gsasl_gs2_client_finish (Gsasl_session * sctx,
-				      void *mech_data);
-extern int _gsasl_gs2_client_encode (Gsasl_session * sctx,
-				     void *mech_data,
-				     const char *input, size_t input_len,
-				     char **output, size_t * output_len);
-extern int _gsasl_gs2_client_decode (Gsasl_session * sctx,
-				     void *mech_data,
-				     const char *input, size_t input_len,
-				     char **output, size_t * output_len);
+extern void _gsasl_gs2_client_finish (Gsasl_session * sctx, void *mech_data);
 
-extern int _gsasl_gs2_server_start (Gsasl_session * sctx,
-				    void **mech_data);
+extern int _gsasl_gs2_server_start (Gsasl_session * sctx, void **mech_data);
 extern int _gsasl_gs2_server_step (Gsasl_session * sctx,
 				   void *mech_data,
 				   const char *input, size_t input_len,
 				   char **output, size_t * output_len);
-extern void _gsasl_gs2_server_finish (Gsasl_session * sctx,
-				      void *mech_data);
+extern void _gsasl_gs2_server_finish (Gsasl_session * sctx, void *mech_data);
 
 #endif /* GS2_H */
