@@ -1,5 +1,5 @@
 /* client.c --- OPENID20 mechanism, client side.
- * Copyright (C) 2011-2012 Simon Josefsson
+ * Copyright (C) 2011-2019 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -90,9 +90,11 @@ _gsasl_openid20_client_step (Gsasl_session * sctx,
 
     case 1:
       {
-	gsasl_property_set_raw (sctx, GSASL_REDIRECT_URL, input, input_len);
+	gsasl_property_set_raw (sctx, GSASL_OPENID20_REDIRECT_URL,
+				input, input_len);
 
-	res = gsasl_callback (NULL, sctx, GSASL_AUTHENTICATE_IN_BROWSER);
+	res = gsasl_callback (NULL, sctx,
+			      GSASL_OPENID20_AUTHENTICATE_IN_BROWSER);
 	if (res != GSASL_OK)
 	  return res;
 
