@@ -1,5 +1,5 @@
 /* client.c --- SAML20 mechanism, client side.
- * Copyright (C) 2010-2012  Simon Josefsson
+ * Copyright (C) 2010-2019 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,7 +21,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 /* Get specification. */
@@ -72,22 +72,22 @@ _gsasl_saml20_client_step (Gsasl_session * sctx,
     case 0:
       {
 	const char *authzid = gsasl_property_get (sctx, GSASL_AUTHZID);
-	const char *p;
+	const char *idp =
+	  gsasl_property_get (sctx, GSASL_SAML20_IDP_IDENTIFIER);
 
-	p = gsasl_property_get (sctx, GSASL_SAML20_IDP_IDENTIFIER);
-	if (!p || !*p)
+	if (!idp || !*idp)
 	  return GSASL_NO_SAML20_IDP_IDENTIFIER;
 
 	res = _gsasl_gs2_generate_header (false, 'n', NULL, authzid,
-					  strlen (p), p,
+					  strlen (idp), idp,
 					  output, output_len);
 	if (res != GSASL_OK)
 	  return res;
 
 	res = GSASL_NEEDS_MORE;
 	state->step++;
-	break;
       }
+      break;
 
     case 1:
       {
@@ -96,12 +96,15 @@ _gsasl_saml20_client_step (Gsasl_session * sctx,
 
 	res = gsasl_callback (NULL, sctx,
 			      GSASL_SAML20_AUTHENTICATE_IN_BROWSER);
-	if (res == GSASL_OK)
-	  {
-	    *output_len = 0;
-	    *output = NULL;
-	  }
+	if (res != GSASL_OK)
+	  return res;
 
+	*output_len = 1;
+	*output = strdup ("=");
+	if (!*output)
+	  return GSASL_MALLOC_ERROR;
+
+	res = GSASL_OK;
 	state->step++;
       }
       break;
