@@ -1,5 +1,5 @@
 /* scram.h --- Prototypes for SCRAM mechanism
- * Copyright (C) 2009  Simon Josefsson
+ * Copyright (C) 2009-2019 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -26,11 +26,15 @@
 #include <gsasl.h>
 
 #define GSASL_SCRAM_SHA1_NAME "SCRAM-SHA-1"
+#define GSASL_SCRAM_SHA1_PLUS_NAME "SCRAM-SHA-1-PLUS"
 
 extern Gsasl_mechanism gsasl_scram_sha1_mechanism;
+extern Gsasl_mechanism gsasl_scram_sha1_plus_mechanism;
+
+int _gsasl_scram_sha1_client_start (Gsasl_session * sctx, void **mech_data);
 
 int
-_gsasl_scram_sha1_client_start (Gsasl_session * sctx, void **mech_data);
+_gsasl_scram_sha1_plus_client_start (Gsasl_session * sctx, void **mech_data);
 
 int
 _gsasl_scram_sha1_client_step (Gsasl_session * sctx,
@@ -38,12 +42,13 @@ _gsasl_scram_sha1_client_step (Gsasl_session * sctx,
 			       const char *input, size_t input_len,
 			       char **output, size_t * output_len);
 
-void
-_gsasl_scram_sha1_client_finish (Gsasl_session * sctx, void *mech_data);
+void _gsasl_scram_sha1_client_finish (Gsasl_session * sctx, void *mech_data);
 
 
+int _gsasl_scram_sha1_server_start (Gsasl_session * sctx, void **mech_data);
+
 int
-_gsasl_scram_sha1_server_start (Gsasl_session * sctx, void **mech_data);
+_gsasl_scram_sha1_plus_server_start (Gsasl_session * sctx, void **mech_data);
 
 int
 _gsasl_scram_sha1_server_step (Gsasl_session * sctx,
@@ -52,7 +57,6 @@ _gsasl_scram_sha1_server_step (Gsasl_session * sctx,
 			       size_t input_len,
 			       char **output, size_t * output_len);
 
-void
-_gsasl_scram_sha1_server_finish (Gsasl_session * sctx, void *mech_data);
+void _gsasl_scram_sha1_server_finish (Gsasl_session * sctx, void *mech_data);
 
 #endif /* SCRAM_H */
