@@ -1,5 +1,5 @@
 /* validate.c --- Validate consistency of SCRAM tokens.
- * Copyright (C) 2009-2012 Simon Josefsson
+ * Copyright (C) 2009-2019 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,7 +21,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 /* Get prototypes. */
@@ -56,8 +56,7 @@ scram_valid_client_first (struct scram_client_first *cf)
       const char *p = cf->cbname;
 
       while (*p && strchr ("ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-			   "abcdefghijklmnopqrstuvwxyz"
-			   "0123456789.-", *p))
+			   "abcdefghijklmnopqrstuvwxyz" "0123456789.-", *p))
 	p++;
       if (*p)
 	return false;
@@ -79,7 +78,7 @@ scram_valid_client_first (struct scram_client_first *cf)
 }
 
 bool
-scram_valid_server_first (struct scram_server_first *sf)
+scram_valid_server_first (struct scram_server_first * sf)
 {
   /* We require a non-zero nonce. */
   if (sf->nonce == NULL || *sf->nonce == '\0')
@@ -104,7 +103,7 @@ scram_valid_server_first (struct scram_server_first *sf)
 }
 
 bool
-scram_valid_client_final (struct scram_client_final *cl)
+scram_valid_client_final (struct scram_client_final * cl)
 {
   /* We require a non-zero cbind. */
   if (cl->cbind == NULL || *cl->cbind == '\0')
@@ -134,7 +133,7 @@ scram_valid_client_final (struct scram_client_final *cl)
 }
 
 bool
-scram_valid_server_final (struct scram_server_final *sl)
+scram_valid_server_final (struct scram_server_final * sl)
 {
   /* We require a non-zero verifier. */
   if (sl->verifier == NULL || *sl->verifier == '\0')
