@@ -1,5 +1,5 @@
 /* crypto.c --- Simple crypto wrappers for applications.
- * Copyright (C) 2002-2012 Simon Josefsson
+ * Copyright (C) 2002-2019 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -59,7 +59,7 @@ gsasl_random (char *data, size_t datalen)
  * gsasl_md5:
  * @in: input character array of data to hash.
  * @inlen: length of input character array of data to hash.
- * @out: newly allocated character array with hash of data.
+ * @out: newly allocated 16-byte character array with hash of data.
  *
  * Compute hash of data using MD5.  The @out buffer must be
  * deallocated by the caller.
@@ -67,9 +67,9 @@ gsasl_random (char *data, size_t datalen)
  * Return value: Returns %GSASL_OK iff successful.
  **/
 int
-gsasl_md5 (const char *in, size_t inlen, char *out[16])
+gsasl_md5 (const char *in, size_t inlen, char *out[])
 {
-  *out = malloc (16);
+  *out = malloc (GC_MD5_DIGEST_SIZE);
   if (!*out)
     return GSASL_MALLOC_ERROR;
   return gc_md5 (in, inlen, *out);
@@ -81,7 +81,7 @@ gsasl_md5 (const char *in, size_t inlen, char *out[16])
  * @keylen: length of input character array with key to use.
  * @in: input character array of data to hash.
  * @inlen: length of input character array of data to hash.
- * @outhash: newly allocated character array with keyed hash of data.
+ * @outhash: newly allocated 16-byte character array with keyed hash of data.
  *
  * Compute keyed checksum of data using HMAC-MD5.  The @outhash buffer
  * must be deallocated by the caller.
@@ -90,9 +90,9 @@ gsasl_md5 (const char *in, size_t inlen, char *out[16])
  **/
 int
 gsasl_hmac_md5 (const char *key, size_t keylen,
-		const char *in, size_t inlen, char *outhash[16])
+		const char *in, size_t inlen, char *outhash[])
 {
-  *outhash = malloc (16);
+  *outhash = malloc (GC_MD5_DIGEST_SIZE);
   if (!*outhash)
     return GSASL_MALLOC_ERROR;
   return gc_hmac_md5 (key, keylen, in, inlen, *outhash);
@@ -102,7 +102,7 @@ gsasl_hmac_md5 (const char *key, size_t keylen,
  * gsasl_sha1:
  * @in: input character array of data to hash.
  * @inlen: length of input character array of data to hash.
- * @out: newly allocated character array with hash of data.
+ * @out: newly allocated 20-byte character array with hash of data.
  *
  * Compute hash of data using SHA1.  The @out buffer must be
  * deallocated by the caller.
@@ -112,9 +112,9 @@ gsasl_hmac_md5 (const char *key, size_t keylen,
  * Since: 1.3
  **/
 int
-gsasl_sha1 (const char *in, size_t inlen, char *out[20])
+gsasl_sha1 (const char *in, size_t inlen, char *out[])
 {
-  *out = malloc (20);
+  *out = malloc (GC_SHA1_DIGEST_SIZE);
   if (!*out)
     return GSASL_MALLOC_ERROR;
   return gc_sha1 (in, inlen, *out);
@@ -126,7 +126,7 @@ gsasl_sha1 (const char *in, size_t inlen, char *out[20])
  * @keylen: length of input character array with key to use.
  * @in: input character array of data to hash.
  * @inlen: length of input character array of data to hash.
- * @outhash: newly allocated character array with keyed hash of data.
+ * @outhash: newly allocated 20-byte character array with keyed hash of data.
  *
  * Compute keyed checksum of data using HMAC-SHA1.  The @outhash buffer
  * must be deallocated by the caller.
@@ -137,9 +137,9 @@ gsasl_sha1 (const char *in, size_t inlen, char *out[20])
  **/
 int
 gsasl_hmac_sha1 (const char *key, size_t keylen,
-		 const char *in, size_t inlen, char *outhash[20])
+		 const char *in, size_t inlen, char *outhash[])
 {
-  *outhash = malloc (20);
+  *outhash = malloc (GC_SHA1_DIGEST_SIZE);
   if (!*outhash)
     return GSASL_MALLOC_ERROR;
   return gc_hmac_sha1 (key, keylen, in, inlen, *outhash);
