@@ -1,5 +1,5 @@
 /* init.c --- Entry point for libgsasl.
- * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010  Simon Josefsson
+ * Copyright (C) 2002-2019 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -35,6 +35,8 @@
 #include "securid/securid.h"
 #include "digest-md5/digest-md5.h"
 #include "scram/scram.h"
+#include "saml20/saml20.h"
+#include "openid20/openid20.h"
 
 #include "login/login.h"
 #include "ntlm/x-ntlm.h"
@@ -112,6 +114,18 @@ register_builtin_mechs (Gsasl * ctx)
     return rc;
 #endif /* USE_SCRAM_SHA1 */
 
+#ifdef USE_SAML20
+  rc = gsasl_register (ctx, &gsasl_saml20_mechanism);
+  if (rc != GSASL_OK)
+    return rc;
+#endif /* USE_SAML20 */
+
+#ifdef USE_OPENID20
+  rc = gsasl_register (ctx, &gsasl_openid20_mechanism);
+  if (rc != GSASL_OK)
+    return rc;
+#endif /* USE_OPENID20 */
+
 #ifdef USE_GSSAPI
   rc = gsasl_register (ctx, &gsasl_gssapi_mechanism);
   if (rc != GSASL_OK)
