@@ -1,5 +1,5 @@
 /* callbacks.c --- Implementation of gsasl callbacks.
- * Copyright (C) 2002-2012 Simon Josefsson
+ * Copyright (C) 2002-2019 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -241,7 +241,7 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
 
     default:
       fprintf (stderr,
-	       "warning: mechanism requested unsupported property `%d'\n",
+	       "warning: mechanism requested unsupported property `%u'\n",
 	       prop);
       break;
     }
