@@ -1,5 +1,5 @@
 /* cram-md5.c --- Test the CRAM-MD5 mechanism.
- * Copyright (C) 2002-2012 Simon Josefsson
+ * Copyright (C) 2002-2019 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -55,7 +55,7 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
       break;
 
     default:
-      fail ("Unknown callback property %d\n", prop);
+      fail ("Unknown callback property %u\n", prop);
       break;
     }
 
