@@ -1,5 +1,5 @@
 /* gssapi.c --- Test the GSSAPI mechanism.
- * Copyright (C) 2002-2012 Simon Josefsson
+ * Copyright (C) 2002-2019 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -47,8 +47,8 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
 
   switch (prop)
     {
-    case GSASL_AUTHID:
-      gsasl_property_set (sctx, GSASL_AUTHID, USERNAME[i]);
+    case GSASL_AUTHZID:
+      gsasl_property_set (sctx, GSASL_AUTHZID, USERNAME[i]);
       rc = GSASL_OK;
       break;
 
@@ -80,7 +80,7 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
       break;
 
     default:
-      fail ("Unknown callback property %d\n", prop);
+      fail ("Unknown callback property %u\n", prop);
       break;
     }
 
