@@ -1,5 +1,5 @@
 /* saml20.c --- Test the SAML20 mechanism.
- * Copyright (C) 2010-2012 Simon Josefsson
+ * Copyright (C) 2010-2019 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -84,7 +84,7 @@ client_callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
       break;
 
     default:
-      fail ("Unknown client callback property %d\n", prop);
+      fail ("Unknown client callback property %u\n", prop);
       break;
     }
 
@@ -115,7 +115,7 @@ server_callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
       break;
 
     default:
-      fail ("Unknown server callback property %d\n", prop);
+      fail ("Unknown server callback property %u\n", prop);
       break;
     }
 
