@@ -1,5 +1,5 @@
 /* scramplus.c --- Test the SCRAM-SHA-1-PLUS mechanism.
- * Copyright (C) 2009-2012 Simon Josefsson
+ * Copyright (C) 2009-2019 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -113,7 +113,7 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
       break;
 
     default:
-      fail ("Unknown callback property %d\n", prop);
+      fail ("Unknown callback property %u\n", prop);
       break;
     }
 
